import { value } from './generated-dynamic1.js';

console.log('dynamic2', value);

export { value };
